summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/object_factory.h')
-rw-r--r--kig/objects/object_factory.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kig/objects/object_factory.h b/kig/objects/object_factory.h
index f3a28d66..d99cce8b 100644
--- a/kig/objects/object_factory.h
+++ b/kig/objects/object_factory.h
@@ -94,16 +94,16 @@ public:
ObjectHolder* locus( ObjectCalcer* a, ObjectCalcer* b ) const;
/**
* returns a label with text \p s at point \p c .. It ( and its tqparents )
* is calced already...
*/
ObjectHolder* label(
const TQString& s, const Coordinate& loc,
- bool needframe, const std::vector<ObjectCalcer*>& tqparents,
+ bool needframe, const std::vector<ObjectCalcer*>& parents,
const KigDocument& doc ) const;
ObjectTypeCalcer* labelCalcer(
const TQString& s, const Coordinate& loc,
- bool needframe, const std::vector<ObjectCalcer*>& tqparents,
+ bool needframe, const std::vector<ObjectCalcer*>& parents,
const KigDocument& doc ) const;
/**
@@ -113,7 +113,7 @@ public:
ObjectTypeCalcer* attachedLabelCalcer(
const TQString& s, ObjectCalcer* locationtqparent,
const Coordinate& loc, bool needframe,
- const std::vector<ObjectCalcer*>& tqparents,
+ const std::vector<ObjectCalcer*>& parents,
const KigDocument& doc ) const;
/**
* this has been added because it comes handy when redefining
@@ -127,7 +127,7 @@ public:
ObjectHolder* attachedLabel(
const TQString& s, ObjectCalcer* locationtqparent,
const Coordinate& loc, bool needframe,
- const std::vector<ObjectCalcer*>& tqparents,
+ const std::vector<ObjectCalcer*>& parents,
const KigDocument& doc ) const;
/**
@@ -94,16 +94,16 @@ public:
ObjectHolder* locus( ObjectCalcer* a, ObjectCalcer* b ) const;
/**
- * returns a label with text \p s at point \p c .. It ( and its tqparents )
+ * returns a label with text \p s at point \p c .. It ( and its parents )
* is calced already...
*/